@@ -32,6 +32,8 @@ class Py2NConnectionData:
 class Py2NDeviceData:
     """Data collected from a 2N device."""
 
+    name: str
     model: str
     serial: str
+    firmware: str
     uptime: Optional[datetime]
